@@ -1,8 +1,7 @@
 from uiautomator2 import Device
 from openpyxl.worksheet.worksheet import Worksheet
 
-from sdgs_tools.aplikasi_sdgs.utils import d_get_text
-from .utils import menu_to
+from sdgs_tools.aplikasi_sdgs.utils import d_get_text, menu_to
 
 # resourceId
 DISABILITAS_COL = {
@@ -24,4 +23,4 @@ def get_data_disabilitas(d: Device, ws: Worksheet, row: int):
     menu_to(d, "DISABILITAS")
     for col, resourceId in DISABILITAS_COL.items():
         ws[f"{col}{row}"] = d_get_text(d, resourceId)
-    d(className='android.widget.ScrollView').fling.vert.backward()
+    d(className="android.widget.ScrollView").fling.vert.backward()
