@@ -2,6 +2,7 @@ from typing import List
 
 from .auth import BaseAuth
 from .import_individu import DataIndividu
+from .import_keluarga import DataKeluarga
 
 
 class Sdgs(BaseAuth):
@@ -22,7 +23,7 @@ class Sdgs(BaseAuth):
             json=json_data,
             ignore=True,
         )
-        return bool(res)
+        return bool(res) or res.message == "NIK Kepala Keluarga Sudah Ada"
 
     def validateNik(
         self,
@@ -46,3 +47,13 @@ class Sdgs(BaseAuth):
             json=json_data,
         )
         return res
+
+    def save_keluarga(self, keluarga: DataKeluarga, rt: str, rw: str):
+        data_keluarga = keluarga.make_json(desa=self.token.wilayah, rt=rt, rw=rw)
+        json_data = {"jsonResult": data_keluarga}
+        res = self.api_post_raw(
+            filename="surveyKeluarga/save",
+            cl=str,
+            json=json_data,
+        )
+        return res
